@@ -7,7 +7,7 @@
 #
 
 import logging
-from typing import Any, Optional, Union
+from typing import Any
 import warnings
 from pydantic import RootModel
 from mindbridgeapi.exceptions import ParameterError
@@ -24,7 +24,7 @@ logger = logging.getLogger(__name__)
 
 
 def _warning_if_extra_fields(self: Any) -> Any:
-    """Emits a warning if the model had any extra fields
+    """Emits a warning if the model had any extra fields.
 
     This is used to create a warning if and only if the model had any extra fields, but
     still allow the model to be used. For example:
@@ -51,7 +51,7 @@ def _warning_if_extra_fields(self: Any) -> Any:
 
 
 def _convert_userinfo_to_useritem(v: Any) -> Any:
-    """Converts from UserInfo to UserItem
+    """Converts from UserInfo to UserItem.
 
     If it's a ApiUserInfo or ApiUserInfoRead it changes to UserItem, with just the
     relevant fields set. It also does some extra conversion if it seems to be an API
@@ -63,7 +63,6 @@ def _convert_userinfo_to_useritem(v: Any) -> Any:
     Returns:
         Any: UserItem if possible, the original data otherwise
     """
-
     if not isinstance(v, (ApiUserInfo, ApiUserInfoRead)):
         return v
 
@@ -79,15 +78,15 @@ def _convert_userinfo_to_useritem(v: Any) -> Any:
 
 
 def _convert_json_query(
-    json: Optional[dict[str, Any]], required_key: Optional[str] = None
-) -> dict[str, Union[int, float, bool, str]]:
+    json: dict[str, Any] | None, required_key: str | None = None
+) -> dict[str, int | float | bool | str]:
     if json is None:
         json = {}
 
     mb_query = MindBridgeQuery.model_validate(json)
     json_str = mb_query.model_dump_json(exclude_none=True)
 
-    logger.info(f"Query (get) is: {json_str}")
+    logger.info("Query (get) is: %s", json_str)
 
     if required_key is not None and required_key not in json_str:
         raise ParameterError(
@@ -98,7 +97,7 @@ def _convert_json_query(
             ),
         )
 
-    mb_query_dict: dict[str, Union[int, float, bool, str]] = mb_query.model_dump(
+    mb_query_dict: dict[str, int | float | bool | str] = mb_query.model_dump(
         mode="json", exclude_none=True
     )
     return mb_query_dict
