@@ -12,16 +12,18 @@ from functools import cached_property
 import http.client
 import json
 import logging
-from typing import Optional
+from ssl import CERT_NONE, CERT_REQUIRED
 from urllib3 import PoolManager
 from urllib3.util import Retry, Url, make_headers, parse_url
 from mindbridgeapi.account_groupings import AccountGroupings
 from mindbridgeapi.account_groups import AccountGroups
 from mindbridgeapi.account_mappings import AccountMappings
+from mindbridgeapi.admin_reports import AdminReports
 from mindbridgeapi.analyses import Analyses
 from mindbridgeapi.analysis_results import AnalysisResults
 from mindbridgeapi.analysis_source_types import AnalysisSourceTypes
 from mindbridgeapi.analysis_sources import AnalysisSources
+from mindbridgeapi.analysis_type_configurations import AnalysisTypeConfigurations
 from mindbridgeapi.analysis_types import AnalysisTypes
 from mindbridgeapi.api_tokens import ApiTokens
 from mindbridgeapi.async_results import AsyncResults
@@ -30,16 +32,20 @@ from mindbridgeapi.data_tables import DataTables
 from mindbridgeapi.engagement_account_groupings import EngagementAccountGroupings
 from mindbridgeapi.engagement_account_groups import EngagementAccountGroups
 from mindbridgeapi.engagements import Engagements
+from mindbridgeapi.file_infos import FileInfos
 from mindbridgeapi.file_manager import FileManager
 from mindbridgeapi.file_results import FileResults
 from mindbridgeapi.json_tables import JSONTables
 from mindbridgeapi.libraries import Libraries
 from mindbridgeapi.organizations import Organizations
+from mindbridgeapi.populations import Populations
+from mindbridgeapi.risk_ranges import RiskRanges
 from mindbridgeapi.task_histories import TaskHistories
 from mindbridgeapi.tasks import Tasks
 from mindbridgeapi.transaction_id_previews import TransactionIdPreviews
 from mindbridgeapi.users import Users
 from mindbridgeapi.version import VERSION, get_package_name
+from mindbridgeapi.webhooks import Webhooks
 
 logger = logging.getLogger(__name__)
 
@@ -84,7 +90,7 @@ def _print_to_log(*args: str) -> None:
     logger.debug("HTTP approximate sent headers:\n%s", headers)
 
 
-def _validate_and_get_logstr(*args: str) -> Optional[str]:
+def _validate_and_get_logstr(*args: str) -> str | None:
     expected_number_of_args = 2
     if not isinstance(args, tuple) or len(args) != expected_number_of_args:
         return None
@@ -132,7 +138,7 @@ def _log_multipart(log_bytes: bytes) -> None:
             logger.debug("%s body:\n[Redacted as it was not JSON data]", log_str_prefix)
 
 
-def _pretty_json(in_bytes: bytes) -> Optional[str]:
+def _pretty_json(in_bytes: bytes) -> str | None:
     try:
         body_obj = json.loads(in_bytes)
     except (UnicodeDecodeError, json.JSONDecodeError):
@@ -166,16 +172,20 @@ class Server:
     url: str  # Provided URL, like mycompany.mindbridge.ai
     token: str = field(repr=False)  # API token
     verify_certificate: bool = (
-        True  # If False don't verify the SSL certificate (cert_reqs = "CERT_NONE")
+        True  # If False don't verify the SSL certificate (cert_reqs=CERT_NONE)
     )
     http: PoolManager = field(init=False, repr=False)
     account_groupings: AccountGroupings = field(init=False, repr=False)
     account_groups: AccountGroups = field(init=False, repr=False)
     account_mappings: AccountMappings = field(init=False, repr=False)
+    admin_reports: AdminReports = field(init=False, repr=False)
     analyses: Analyses = field(init=False, repr=False)
     analysis_results: AnalysisResults = field(init=False, repr=False)
     analysis_source_types: AnalysisSourceTypes = field(init=False, repr=False)
     analysis_sources: AnalysisSources = field(init=False, repr=False)
+    analysis_type_configurations: AnalysisTypeConfigurations = field(
+        init=False, repr=False
+    )
     analysis_types: AnalysisTypes = field(init=False, repr=False)
     api_tokens: ApiTokens = field(init=False, repr=False)
     async_results: AsyncResults = field(init=False, repr=False)
@@ -186,15 +196,19 @@ class Server:
     )
     engagement_account_groups: EngagementAccountGroups = field(init=False, repr=False)
     engagements: Engagements = field(init=False, repr=False)
+    file_infos: FileInfos = field(init=False, repr=False)
     file_manager: FileManager = field(init=False, repr=False)
     file_results: FileResults = field(init=False, repr=False)
     json_tables: JSONTables = field(init=False, repr=False)
     libraries: Libraries = field(init=False, repr=False)
     organizations: Organizations = field(init=False, repr=False)
+    populations: Populations = field(init=False, repr=False)
+    risk_ranges: RiskRanges = field(init=False, repr=False)
     task_histories: TaskHistories = field(init=False, repr=False)
     tasks: Tasks = field(init=False, repr=False)
     transaction_id_previews: TransactionIdPreviews = field(init=False, repr=False)
     users: Users = field(init=False, repr=False)
+    webhooks: Webhooks = field(init=False, repr=False)
 
     def __post_init__(self) -> None:
         user_agent = f"{get_package_name()}/{VERSION}"
@@ -206,20 +220,21 @@ class Server:
         # redirect=0 as the base url will always be https
         retries = Retry(connect=3, read=3, redirect=0, other=0)
 
+        cert_reqs = CERT_REQUIRED  # default
         if not self.verify_certificate:
-            self.http = PoolManager(
-                headers=headers, retries=retries, cert_reqs="CERT_NONE"
-            )
-        else:
-            self.http = PoolManager(headers=headers, retries=retries)
+            cert_reqs = CERT_NONE
+
+        self.http = PoolManager(headers=headers, retries=retries, cert_reqs=cert_reqs)
 
         self.account_groupings = AccountGroupings(server=self)
         self.account_groups = AccountGroups(server=self)
         self.account_mappings = AccountMappings(server=self)
+        self.admin_reports = AdminReports(server=self)
         self.analyses = Analyses(server=self)
         self.analysis_results = AnalysisResults(server=self)
         self.analysis_source_types = AnalysisSourceTypes(server=self)
         self.analysis_sources = AnalysisSources(server=self)
+        self.analysis_type_configurations = AnalysisTypeConfigurations(server=self)
         self.analysis_types = AnalysisTypes(server=self)
         self.api_tokens = ApiTokens(server=self)
         self.async_results = AsyncResults(server=self)
@@ -228,15 +243,19 @@ class Server:
         self.engagement_account_groupings = EngagementAccountGroupings(server=self)
         self.engagement_account_groups = EngagementAccountGroups(server=self)
         self.engagements = Engagements(server=self)
+        self.file_infos = FileInfos(server=self)
         self.file_manager = FileManager(server=self)
         self.file_results = FileResults(server=self)
         self.json_tables = JSONTables(server=self)
         self.libraries = Libraries(server=self)
         self.organizations = Organizations(server=self)
+        self.populations = Populations(server=self)
+        self.risk_ranges = RiskRanges(server=self)
         self.task_histories = TaskHistories(server=self)
         self.tasks = Tasks(server=self)
         self.transaction_id_previews = TransactionIdPreviews(server=self)
         self.users = Users(server=self)
+        self.webhooks = Webhooks(server=self)
 
         if logger.getEffectiveLevel() <= logging.DEBUG:
             logger.info("Enabling logging from http.client (for sent DEBUG info)")
