@@ -6,23 +6,35 @@
 #  the prior written consent of MindBridge Analytics Inc.
 #
 
+from typing import Annotated
 from pydantic import ConfigDict, Field, model_validator
 from mindbridgeapi.common_validators import _warning_if_extra_fields
-from mindbridgeapi.generated_pydantic_model.model import ApiTransactionIdSelectionRead
-from mindbridgeapi.generated_pydantic_model.model import Type13 as _TransactionIdType
+from mindbridgeapi.generated_pydantic_model.model import (
+    ApiTransactionIdSelectionRead,
+    Type69 as _TransactionIdType,
+)
 
 TransactionIdType = _TransactionIdType  # Match the type of TransactionIdSelection.type
 
 
 class TransactionIdSelection(ApiTransactionIdSelectionRead):
-    apply_smart_splitter: bool = Field().merge_field_infos(
-        ApiTransactionIdSelectionRead.model_fields["apply_smart_splitter"],
-        default=False,
-    )
-    type: TransactionIdType = Field().merge_field_infos(
-        ApiTransactionIdSelectionRead.model_fields["type"],
-        default=TransactionIdType.COMBINATION,
-    )
+    apply_smart_splitter: Annotated[
+        bool,
+        Field(
+            alias=ApiTransactionIdSelectionRead.model_fields[
+                "apply_smart_splitter"
+            ].alias,
+            description=ApiTransactionIdSelectionRead.model_fields[
+                "apply_smart_splitter"
+            ].description,
+        ),
+    ] = False
+    type: Annotated[
+        TransactionIdType,
+        Field(
+            description=ApiTransactionIdSelectionRead.model_fields["type"].description
+        ),
+    ] = TransactionIdType.COMBINATION
 
     model_config = ConfigDict(
         extra="allow",
